| Type: | Package |
| Title: | Time Feature Extrapolation Using Spectral Analysis and Jack-Knife Resampling |
| Version: | 2.0.0 |
| Description: | Proposes application of spectral analysis and jack-knife resampling for multivariate sequence forecasting using only base R functionality. |
| License: | GPL-3 |
| Encoding: | UTF-8 |
| LazyData: | true |
| RoxygenNote: | 7.3.3 |
| Depends: | R (≥ 3.6) |
| Suggests: | knitr, rmarkdown, testthat (≥ 3.0.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-07 06:56:15 UTC; gianc |
| Author: | Giancarlo Vercellino [aut, cre] |
| Maintainer: | Giancarlo Vercellino <giancarlo.vercellino@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-07 07:10:02 UTC |
Spectral forecasting with jackknife resampling
Description
Automatic jack-knife of spectral analysis for time feature extrapolation
Usage
spooky(
df,
seq_len = NULL,
lno = NULL,
n_samp = 30,
n_windows = 3,
ci = 0.8,
smoother = FALSE,
dates = NULL,
error_scale = "naive",
error_benchmark = "naive",
seed = 42
)
Arguments
df |
Numeric or categorical time-feature data frame. |
seq_len |
Forecast horizon or range of horizons to search. |
lno |
Jackknife leave-out value or search range. |
n_samp |
Number of candidate configurations. |
n_windows |
Number of validation windows. |
ci |
Confidence level for prediction summaries. |
smoother |
Apply a moving-average smoother to numeric data. |
dates |
Optional Date vector matching 'df'. |
error_scale |
Scale used by numeric error metrics. |
error_benchmark |
Benchmark used by relative error metrics. |
seed |
Random seed. |
Value
An object of class 'spooky_fit'.
Author(s)
Maintainer: Giancarlo Vercellino giancarlo.vercellino@gmail.com
time features example: IBM and Microsoft Close Prices
Description
A data frame with with daily with daily prices for IBM and Microsoft since March 2017.
Usage
time_features
Format
A data frame with 2 columns and 1324 rows.
finance.yahoo.com